# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/billing/v1/billable_object.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/billing/v1/billable_object.proto',
  package='yandex.cloud.billing.v1',
  syntax='proto3',
  serialized_options=b'\n\033yandex.cloud.api.billing.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/billing/v1;billing',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n-yandex/cloud/billing/v1/billable_object.proto\x12\x17yandex.cloud.billing.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"*\n\x0e\x42illableObject\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\"\x8d\x01\n\x15\x42illableObjectBinding\x12\x32\n\x0e\x65\x66\x66\x65\x63tive_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12@\n\x0f\x62illable_object\x18\x02 \x01(\x0b\x32\'.yandex.cloud.billing.v1.BillableObjectBb\n\x1byandex.cloud.api.billing.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/billing/v1;billingb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])




_BILLABLEOBJECT = _descriptor.Descriptor(
  name='BillableObject',
  full_name='yandex.cloud.billing.v1.BillableObject',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yandex.cloud.billing.v1.BillableObject.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='yandex.cloud.billing.v1.BillableObject.type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=107,
  serialized_end=149,
)


_BILLABLEOBJECTBINDING = _descriptor.Descriptor(
  name='BillableObjectBinding',
  full_name='yandex.cloud.billing.v1.BillableObjectBinding',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='effective_time', full_name='yandex.cloud.billing.v1.BillableObjectBinding.effective_time', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='billable_object', full_name='yandex.cloud.billing.v1.BillableObjectBinding.billable_object', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=152,
  serialized_end=293,
)

_BILLABLEOBJECTBINDING.fields_by_name['effective_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_BILLABLEOBJECTBINDING.fields_by_name['billable_object'].message_type = _BILLABLEOBJECT
DESCRIPTOR.message_types_by_name['BillableObject'] = _BILLABLEOBJECT
DESCRIPTOR.message_types_by_name['BillableObjectBinding'] = _BILLABLEOBJECTBINDING
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

BillableObject = _reflection.GeneratedProtocolMessageType('BillableObject', (_message.Message,), {
  'DESCRIPTOR' : _BILLABLEOBJECT,
  '__module__' : 'yandex.cloud.billing.v1.billable_object_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.billing.v1.BillableObject)
  })
_sym_db.RegisterMessage(BillableObject)

BillableObjectBinding = _reflection.GeneratedProtocolMessageType('BillableObjectBinding', (_message.Message,), {
  'DESCRIPTOR' : _BILLABLEOBJECTBINDING,
  '__module__' : 'yandex.cloud.billing.v1.billable_object_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.billing.v1.BillableObjectBinding)
  })
_sym_db.RegisterMessage(BillableObjectBinding)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/iot/broker/v1/broker.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/iot/broker/v1/broker.proto',
  package='yandex.cloud.iot.broker.v1',
  syntax='proto3',
  serialized_options=b'\n\036yandex.cloud.api.iot.broker.v1ZEgithub.com/yandex-cloud/go-genproto/yandex/cloud/iot/broker/v1;broker',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\'yandex/cloud/iot/broker/v1/broker.proto\x12\x1ayandex.cloud.iot.broker.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\xee\x02\n\x06\x42roker\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12>\n\x06labels\x18\x06 \x03(\x0b\x32..yandex.cloud.iot.broker.v1.Broker.LabelsEntry\x12\x39\n\x06status\x18\x07 \x01(\x0e\x32).yandex.cloud.iot.broker.v1.Broker.Status\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"H\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\n\n\x06\x41\x43TIVE\x10\x02\x12\x0c\n\x08\x44\x45LETING\x10\x03\"\x85\x01\n\x11\x42rokerCertificate\x12\x11\n\tbroker_id\x18\x01 \x01(\t\x12\x13\n\x0b\x66ingerprint\x18\x02 \x01(\t\x12\x18\n\x10\x63\x65rtificate_data\x18\x03 \x01(\t\x12.\n\ncreated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"_\n\x0e\x42rokerPassword\x12\x11\n\tbroker_id\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampBg\n\x1eyandex.cloud.api.iot.broker.v1ZEgithub.com/yandex-cloud/go-genproto/yandex/cloud/iot/broker/v1;brokerb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])



_BROKER_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='yandex.cloud.iot.broker.v1.Broker.Status',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATUS_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CREATING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ACTIVE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DELETING', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=399,
  serialized_end=471,
)
_sym_db.RegisterEnumDescriptor(_BROKER_STATUS)


_BROKER_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.iot.broker.v1.Broker.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.iot.broker.v1.Broker.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.iot.broker.v1.Broker.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=352,
  serialized_end=397,
)

_BROKER = _descriptor.Descriptor(
  name='Broker',
  full_name='yandex.cloud.iot.broker.v1.Broker',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yandex.cloud.iot.broker.v1.Broker.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.iot.broker.v1.Broker.folder_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='yandex.cloud.iot.broker.v1.Broker.created_at', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.iot.broker.v1.Broker.name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.iot.broker.v1.Broker.description', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.iot.broker.v1.Broker.labels', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='yandex.cloud.iot.broker.v1.Broker.status', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_BROKER_LABELSENTRY, ],
  enum_types=[
    _BROKER_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=105,
  serialized_end=471,
)


_BROKERCERTIFICATE = _descriptor.Descriptor(
  name='BrokerCertificate',
  full_name='yandex.cloud.iot.broker.v1.BrokerCertificate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='broker_id', full_name='yandex.cloud.iot.broker.v1.BrokerCertificate.broker_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fingerprint', full_name='yandex.cloud.iot.broker.v1.BrokerCertificate.fingerprint', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='certificate_data', full_name='yandex.cloud.iot.broker.v1.BrokerCertificate.certificate_data', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='yandex.cloud.iot.broker.v1.BrokerCertificate.created_at', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=474,
  serialized_end=607,
)


_BROKERPASSWORD = _descriptor.Descriptor(
  name='BrokerPassword',
  full_name='yandex.cloud.iot.broker.v1.BrokerPassword',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='broker_id', full_name='yandex.cloud.iot.broker.v1.BrokerPassword.broker_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='yandex.cloud.iot.broker.v1.BrokerPassword.id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='yandex.cloud.iot.broker.v1.BrokerPassword.created_at', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=609,
  serialized_end=704,
)

_BROKER_LABELSENTRY.containing_type = _BROKER
_BROKER.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_BROKER.fields_by_name['labels'].message_type = _BROKER_LABELSENTRY
_BROKER.fields_by_name['status'].enum_type = _BROKER_STATUS
_BROKER_STATUS.containing_type = _BROKER
_BROKERCERTIFICATE.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_BROKERPASSWORD.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
DESCRIPTOR.message_types_by_name['Broker'] = _BROKER
DESCRIPTOR.message_types_by_name['BrokerCertificate'] = _BROKERCERTIFICATE
DESCRIPTOR.message_types_by_name['BrokerPassword'] = _BROKERPASSWORD
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Broker = _reflection.GeneratedProtocolMessageType('Broker', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _BROKER_LABELSENTRY,
    '__module__' : 'yandex.cloud.iot.broker.v1.broker_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.iot.broker.v1.Broker.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _BROKER,
  '__module__' : 'yandex.cloud.iot.broker.v1.broker_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.iot.broker.v1.Broker)
  })
_sym_db.RegisterMessage(Broker)
_sym_db.RegisterMessage(Broker.LabelsEntry)

BrokerCertificate = _reflection.GeneratedProtocolMessageType('BrokerCertificate', (_message.Message,), {
  'DESCRIPTOR' : _BROKERCERTIFICATE,
  '__module__' : 'yandex.cloud.iot.broker.v1.broker_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.iot.broker.v1.BrokerCertificate)
  })
_sym_db.RegisterMessage(BrokerCertificate)

BrokerPassword = _reflection.GeneratedProtocolMessageType('BrokerPassword', (_message.Message,), {
  'DESCRIPTOR' : _BROKERPASSWORD,
  '__module__' : 'yandex.cloud.iot.broker.v1.broker_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.iot.broker.v1.BrokerPassword)
  })
_sym_db.RegisterMessage(BrokerPassword)


DESCRIPTOR._options = None
_BROKER_LABELSENTRY._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/iam/v1/key.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/iam/v1/key.proto',
  package='yandex.cloud.iam.v1',
  syntax='proto3',
  serialized_options=b'\n\027yandex.cloud.api.iam.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/iam/v1;iam',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1dyandex/cloud/iam/v1/key.proto\x12\x13yandex.cloud.iam.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\xad\x02\n\x03Key\x12\n\n\x02id\x18\x01 \x01(\t\x12\x19\n\x0fuser_account_id\x18\x02 \x01(\tH\x00\x12\x1c\n\x12service_account_id\x18\x03 \x01(\tH\x00\x12.\n\ncreated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\x39\n\rkey_algorithm\x18\x06 \x01(\x0e\x32\".yandex.cloud.iam.v1.Key.Algorithm\x12\x12\n\npublic_key\x18\x07 \x01(\t\"B\n\tAlgorithm\x12\x19\n\x15\x41LGORITHM_UNSPECIFIED\x10\x00\x12\x0c\n\x08RSA_2048\x10\x01\x12\x0c\n\x08RSA_4096\x10\x02\x42\t\n\x07subjectBV\n\x17yandex.cloud.api.iam.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/iam/v1;iamb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])



_KEY_ALGORITHM = _descriptor.EnumDescriptor(
  name='Algorithm',
  full_name='yandex.cloud.iam.v1.Key.Algorithm',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ALGORITHM_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RSA_2048', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RSA_4096', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=312,
  serialized_end=378,
)
_sym_db.RegisterEnumDescriptor(_KEY_ALGORITHM)


_KEY = _descriptor.Descriptor(
  name='Key',
  full_name='yandex.cloud.iam.v1.Key',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yandex.cloud.iam.v1.Key.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_account_id', full_name='yandex.cloud.iam.v1.Key.user_account_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='service_account_id', full_name='yandex.cloud.iam.v1.Key.service_account_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='yandex.cloud.iam.v1.Key.created_at', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.iam.v1.Key.description', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='key_algorithm', full_name='yandex.cloud.iam.v1.Key.key_algorithm', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='public_key', full_name='yandex.cloud.iam.v1.Key.public_key', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _KEY_ALGORITHM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='subject', full_name='yandex.cloud.iam.v1.Key.subject',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=88,
  serialized_end=389,
)

_KEY.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_KEY.fields_by_name['key_algorithm'].enum_type = _KEY_ALGORITHM
_KEY_ALGORITHM.containing_type = _KEY
_KEY.oneofs_by_name['subject'].fields.append(
  _KEY.fields_by_name['user_account_id'])
_KEY.fields_by_name['user_account_id'].containing_oneof = _KEY.oneofs_by_name['subject']
_KEY.oneofs_by_name['subject'].fields.append(
  _KEY.fields_by_name['service_account_id'])
_KEY.fields_by_name['service_account_id'].containing_oneof = _KEY.oneofs_by_name['subject']
DESCRIPTOR.message_types_by_name['Key'] = _KEY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Key = _reflection.GeneratedProtocolMessageType('Key', (_message.Message,), {
  'DESCRIPTOR' : _KEY,
  '__module__' : 'yandex.cloud.iam.v1.key_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.iam.v1.Key)
  })
_sym_db.RegisterMessage(Key)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/ydb/v1/database.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.ydb.v1 import backup_pb2 as yandex_dot_cloud_dot_ydb_dot_v1_dot_backup__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/ydb/v1/database.proto',
  package='yandex.cloud.ydb.v1',
  syntax='proto3',
  serialized_options=b'\n\027yandex.cloud.api.ydb.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/ydb/v1;ydb',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\"yandex/cloud/ydb/v1/database.proto\x12\x13yandex.cloud.ydb.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dyandex/cloud/validation.proto\x1a yandex/cloud/ydb/v1/backup.proto\"\x91\t\n\x08\x44\x61tabase\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\x34\n\x06status\x18\x06 \x01(\x0e\x32$.yandex.cloud.ydb.v1.Database.Status\x12\x10\n\x08\x65ndpoint\x18\x08 \x01(\t\x12\x1a\n\x12resource_preset_id\x18\t \x01(\t\x12:\n\x0estorage_config\x18\n \x01(\x0b\x32\".yandex.cloud.ydb.v1.StorageConfig\x12\x36\n\x0cscale_policy\x18\x0b \x01(\x0b\x32 .yandex.cloud.ydb.v1.ScalePolicy\x12\x12\n\nnetwork_id\x18\x0c \x01(\t\x12\x12\n\nsubnet_ids\x18\r \x03(\t\x12<\n\x0ezonal_database\x18\x0e \x01(\x0b\x32\".yandex.cloud.ydb.v1.ZonalDatabaseH\x00\x12\x42\n\x11regional_database\x18\x0f \x01(\x0b\x32%.yandex.cloud.ydb.v1.RegionalDatabaseH\x00\x12\x44\n\x12\x64\x65\x64icated_database\x18\x12 \x01(\x0b\x32&.yandex.cloud.ydb.v1.DedicatedDatabaseH\x00\x12\x46\n\x13serverless_database\x18\x13 \x01(\x0b\x32\'.yandex.cloud.ydb.v1.ServerlessDatabaseH\x00\x12\x19\n\x11\x61ssign_public_ips\x18\x10 \x01(\x08\x12\x13\n\x0blocation_id\x18\x11 \x01(\t\x12\x39\n\x06labels\x18\x14 \x03(\x0b\x32).yandex.cloud.ydb.v1.Database.LabelsEntry\x12\x38\n\rbackup_config\x18\x15 \x01(\x0b\x32!.yandex.cloud.ydb.v1.BackupConfig\x12\x1d\n\x15\x64ocument_api_endpoint\x18\x16 \x01(\t\x12\x1c\n\x14kinesis_api_endpoint\x18\x17 \x01(\t\x12@\n\x11monitoring_config\x18\x18 \x01(\x0b\x32%.yandex.cloud.ydb.v1.MonitoringConfig\x12\x1b\n\x13\x64\x65letion_protection\x18\x19 \x01(\x08\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x81\x01\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x10\n\x0cPROVISIONING\x10\x01\x12\x0b\n\x07RUNNING\x10\x02\x12\x0c\n\x08UPDATING\x10\x04\x12\t\n\x05\x45RROR\x10\x05\x12\x0c\n\x08\x44\x45LETING\x10\x06\x12\x0c\n\x08STARTING\x10\x07\x12\x0b\n\x07STOPPED\x10\x08\x42\x0f\n\rdatabase_type\"\x82\x06\n\x0e\x41lertParameter\x12Z\n\x16\x64ouble_parameter_value\x18\x01 \x01(\x0b\x32\x38.yandex.cloud.ydb.v1.AlertParameter.DoubleParameterValueH\x00\x12\\\n\x17integer_parameter_value\x18\x02 \x01(\x0b\x32\x39.yandex.cloud.ydb.v1.AlertParameter.IntegerParameterValueH\x00\x12V\n\x14text_parameter_value\x18\x03 \x01(\x0b\x32\x36.yandex.cloud.ydb.v1.AlertParameter.TextParameterValueH\x00\x12_\n\x19text_list_parameter_value\x18\x04 \x01(\x0b\x32:.yandex.cloud.ydb.v1.AlertParameter.TextListParameterValueH\x00\x12\x61\n\x1alabel_list_parameter_value\x18\x05 \x01(\x0b\x32;.yandex.cloud.ydb.v1.AlertParameter.LabelListParameterValueH\x00\x1a\x33\n\x14\x44oubleParameterValue\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x01\x1a\x34\n\x15IntegerParameterValue\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x03\x1a\x31\n\x12TextParameterValue\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\x1a\x36\n\x16TextListParameterValue\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06values\x18\x02 \x03(\t\x1a\x37\n\x17LabelListParameterValue\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06values\x18\x02 \x03(\tB\x0b\n\tparameter\"\xa2\x01\n\x13NotificationChannel\x12\x1f\n\x17notification_channel_id\x18\x01 \x01(\t\x12I\n\x15notify_about_statuses\x18\x02 \x03(\x0e\x32*.yandex.cloud.ydb.v1.AlertEvaluationStatus\x12\x1f\n\x17repeate_notify_delay_ms\x18\x03 \x01(\x03\"\x9e\x02\n\x05\x41lert\x12\x10\n\x08\x61lert_id\x18\x01 \x01(\t\x12\x19\n\x11\x61lert_template_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12G\n\x15notification_channels\x18\x05 \x03(\x0b\x32(.yandex.cloud.ydb.v1.NotificationChannel\x12=\n\x10\x61lert_parameters\x18\x06 \x03(\x0b\x32#.yandex.cloud.ydb.v1.AlertParameter\x12=\n\x10\x61lert_thresholds\x18\x07 \x03(\x0b\x32#.yandex.cloud.ydb.v1.AlertParameter\">\n\x10MonitoringConfig\x12*\n\x06\x61lerts\x18\x01 \x03(\x0b\x32\x1a.yandex.cloud.ydb.v1.Alert\"\xe6\x01\n\x11\x44\x65\x64icatedDatabase\x12\x1a\n\x12resource_preset_id\x18\x01 \x01(\t\x12:\n\x0estorage_config\x18\x02 \x01(\x0b\x32\".yandex.cloud.ydb.v1.StorageConfig\x12\x36\n\x0cscale_policy\x18\x03 \x01(\x0b\x32 .yandex.cloud.ydb.v1.ScalePolicy\x12\x12\n\nnetwork_id\x18\x04 \x01(\t\x12\x12\n\nsubnet_ids\x18\x05 \x03(\t\x12\x19\n\x11\x61ssign_public_ips\x18\x06 \x01(\x08\"\xad\x01\n\x12ServerlessDatabase\x12\x1c\n\x14throttling_rcu_limit\x18\x01 \x01(\x03\x12\x1a\n\x12storage_size_limit\x18\x02 \x01(\x03\x12#\n\x1b\x65nable_throttling_rcu_limit\x18\x03 \x01(\x08\x12\x1d\n\x15provisioned_rcu_limit\x18\x04 \x01(\x03\x12\x19\n\x11topic_write_quota\x18\x05 \x01(\x03\"&\n\rZonalDatabase\x12\x15\n\x07zone_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"+\n\x10RegionalDatabase\x12\x17\n\tregion_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"\x8a\x01\n\x0bScalePolicy\x12\x42\n\x0b\x66ixed_scale\x18\x01 \x01(\x0b\x32+.yandex.cloud.ydb.v1.ScalePolicy.FixedScaleH\x00\x1a#\n\nFixedScale\x12\x15\n\x04size\x18\x01 \x01(\x03\x42\x07\xfa\xc7\x31\x03>=1B\x12\n\nscale_type\x12\x04\xc0\xc1\x31\x01\"q\n\rStorageConfig\x12\x44\n\x0fstorage_options\x18\x01 \x03(\x0b\x32\".yandex.cloud.ydb.v1.StorageOptionB\x07\x82\xc8\x31\x03>=1\x12\x1a\n\x12storage_size_limit\x18\x02 \x01(\x03\"=\n\rStorageOption\x12\x17\n\x0fstorage_type_id\x18\x01 \x01(\t\x12\x13\n\x0bgroup_count\x18\x02 \x01(\x03*\xed\x01\n\x15\x41lertEvaluationStatus\x12\'\n#ALERT_EVALUATION_STATUS_UNSPECIFIED\x10\x00\x12\x1e\n\x1a\x41LERT_EVALUATION_STATUS_OK\x10\x01\x12#\n\x1f\x41LERT_EVALUATION_STATUS_NO_DATA\x10\x02\x12!\n\x1d\x41LERT_EVALUATION_STATUS_ERROR\x10\x03\x12!\n\x1d\x41LERT_EVALUATION_STATUS_ALARM\x10\x04\x12 \n\x1c\x41LERT_EVALUATION_STATUS_WARN\x10\x05\x42V\n\x17yandex.cloud.api.ydb.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/ydb/v1;ydbb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_ydb_dot_v1_dot_backup__pb2.DESCRIPTOR,])

_ALERTEVALUATIONSTATUS = _descriptor.EnumDescriptor(
  name='AlertEvaluationStatus',
  full_name='yandex.cloud.ydb.v1.AlertEvaluationStatus',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ALERT_EVALUATION_STATUS_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ALERT_EVALUATION_STATUS_OK', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ALERT_EVALUATION_STATUS_NO_DATA', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ALERT_EVALUATION_STATUS_ERROR', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ALERT_EVALUATION_STATUS_ALARM', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ALERT_EVALUATION_STATUS_WARN', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3434,
  serialized_end=3671,
)
_sym_db.RegisterEnumDescriptor(_ALERTEVALUATIONSTATUS)

AlertEvaluationStatus = enum_type_wrapper.EnumTypeWrapper(_ALERTEVALUATIONSTATUS)
ALERT_EVALUATION_STATUS_UNSPECIFIED = 0
ALERT_EVALUATION_STATUS_OK = 1
ALERT_EVALUATION_STATUS_NO_DATA = 2
ALERT_EVALUATION_STATUS_ERROR = 3
ALERT_EVALUATION_STATUS_ALARM = 4
ALERT_EVALUATION_STATUS_WARN = 5


_DATABASE_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='yandex.cloud.ydb.v1.Database.Status',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATUS_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PROVISIONING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RUNNING', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UPDATING', index=3, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ERROR', index=4, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DELETING', index=5, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STARTING', index=6, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STOPPED', index=7, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1181,
  serialized_end=1310,
)
_sym_db.RegisterEnumDescriptor(_DATABASE_STATUS)


_DATABASE_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.ydb.v1.Database.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.ydb.v1.Database.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.ydb.v1.Database.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1133,
  serialized_end=1178,
)

_DATABASE = _descriptor.Descriptor(
  name='Database',
  full_name='yandex.cloud.ydb.v1.Database',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yandex.cloud.ydb.v1.Database.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.ydb.v1.Database.folder_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='yandex.cloud.ydb.v1.Database.created_at', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.ydb.v1.Database.name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.ydb.v1.Database.description', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='yandex.cloud.ydb.v1.Database.status', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='endpoint', full_name='yandex.cloud.ydb.v1.Database.endpoint', index=6,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resource_preset_id', full_name='yandex.cloud.ydb.v1.Database.resource_preset_id', index=7,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='storage_config', full_name='yandex.cloud.ydb.v1.Database.storage_config', index=8,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scale_policy', full_name='yandex.cloud.ydb.v1.Database.scale_policy', index=9,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='network_id', full_name='yandex.cloud.ydb.v1.Database.network_id', index=10,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subnet_ids', full_name='yandex.cloud.ydb.v1.Database.subnet_ids', index=11,
      number=13, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='zonal_database', full_name='yandex.cloud.ydb.v1.Database.zonal_database', index=12,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='regional_database', full_name='yandex.cloud.ydb.v1.Database.regional_database', index=13,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dedicated_database', full_name='yandex.cloud.ydb.v1.Database.dedicated_database', index=14,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='serverless_database', full_name='yandex.cloud.ydb.v1.Database.serverless_database', index=15,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='assign_public_ips', full_name='yandex.cloud.ydb.v1.Database.assign_public_ips', index=16,
      number=16, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='location_id', full_name='yandex.cloud.ydb.v1.Database.location_id', index=17,
      number=17, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.ydb.v1.Database.labels', index=18,
      number=20, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='backup_config', full_name='yandex.cloud.ydb.v1.Database.backup_config', index=19,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='document_api_endpoint', full_name='yandex.cloud.ydb.v1.Database.document_api_endpoint', index=20,
      number=22, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='kinesis_api_endpoint', full_name='yandex.cloud.ydb.v1.Database.kinesis_api_endpoint', index=21,
      number=23, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='monitoring_config', full_name='yandex.cloud.ydb.v1.Database.monitoring_config', index=22,
      number=24, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deletion_protection', full_name='yandex.cloud.ydb.v1.Database.deletion_protection', index=23,
      number=25, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_DATABASE_LABELSENTRY, ],
  enum_types=[
    _DATABASE_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='database_type', full_name='yandex.cloud.ydb.v1.Database.database_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=158,
  serialized_end=1327,
)


_ALERTPARAMETER_DOUBLEPARAMETERVALUE = _descriptor.Descriptor(
  name='DoubleParameterValue',
  full_name='yandex.cloud.ydb.v1.AlertParameter.DoubleParameterValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.ydb.v1.AlertParameter.DoubleParameterValue.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.ydb.v1.AlertParameter.DoubleParameterValue.value', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1818,
  serialized_end=1869,
)

_ALERTPARAMETER_INTEGERPARAMETERVALUE = _descriptor.Descriptor(
  name='IntegerParameterValue',
  full_name='yandex.cloud.ydb.v1.AlertParameter.IntegerParameterValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.ydb.v1.AlertParameter.IntegerParameterValue.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.ydb.v1.AlertParameter.IntegerParameterValue.value', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1871,
  serialized_end=1923,
)

_ALERTPARAMETER_TEXTPARAMETERVALUE = _descriptor.Descriptor(
  name='TextParameterValue',
  full_name='yandex.cloud.ydb.v1.AlertParameter.TextParameterValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.ydb.v1.AlertParameter.TextParameterValue.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.ydb.v1.AlertParameter.TextParameterValue.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1925,
  serialized_end=1974,
)

_ALERTPARAMETER_TEXTLISTPARAMETERVALUE = _descriptor.Descriptor(
  name='TextListParameterValue',
  full_name='yandex.cloud.ydb.v1.AlertParameter.TextListParameterValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.ydb.v1.AlertParameter.TextListParameterValue.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='yandex.cloud.ydb.v1.AlertParameter.TextListParameterValue.values', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1976,
  serialized_end=2030,
)

_ALERTPARAMETER_LABELLISTPARAMETERVALUE = _descriptor.Descriptor(
  name='LabelListParameterValue',
  full_name='yandex.cloud.ydb.v1.AlertParameter.LabelListParameterValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.ydb.v1.AlertParameter.LabelListParameterValue.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='yandex.cloud.ydb.v1.AlertParameter.LabelListParameterValue.values', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2032,
  serialized_end=2087,
)

_ALERTPARAMETER = _descriptor.Descriptor(
  name='AlertParameter',
  full_name='yandex.cloud.ydb.v1.AlertParameter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='double_parameter_value', full_name='yandex.cloud.ydb.v1.AlertParameter.double_parameter_value', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='integer_parameter_value', full_name='yandex.cloud.ydb.v1.AlertParameter.integer_parameter_value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='text_parameter_value', full_name='yandex.cloud.ydb.v1.AlertParameter.text_parameter_value', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='text_list_parameter_value', full_name='yandex.cloud.ydb.v1.AlertParameter.text_list_parameter_value', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='label_list_parameter_value', full_name='yandex.cloud.ydb.v1.AlertParameter.label_list_parameter_value', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_ALERTPARAMETER_DOUBLEPARAMETERVALUE, _ALERTPARAMETER_INTEGERPARAMETERVALUE, _ALERTPARAMETER_TEXTPARAMETERVALUE, _ALERTPARAMETER_TEXTLISTPARAMETERVALUE, _ALERTPARAMETER_LABELLISTPARAMETERVALUE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='parameter', full_name='yandex.cloud.ydb.v1.AlertParameter.parameter',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1330,
  serialized_end=2100,
)


_NOTIFICATIONCHANNEL = _descriptor.Descriptor(
  name='NotificationChannel',
  full_name='yandex.cloud.ydb.v1.NotificationChannel',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='notification_channel_id', full_name='yandex.cloud.ydb.v1.NotificationChannel.notification_channel_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='notify_about_statuses', full_name='yandex.cloud.ydb.v1.NotificationChannel.notify_about_statuses', index=1,
      number=2, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='repeate_notify_delay_ms', full_name='yandex.cloud.ydb.v1.NotificationChannel.repeate_notify_delay_ms', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2103,
  serialized_end=2265,
)


_ALERT = _descriptor.Descriptor(
  name='Alert',
  full_name='yandex.cloud.ydb.v1.Alert',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='alert_id', full_name='yandex.cloud.ydb.v1.Alert.alert_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='alert_template_id', full_name='yandex.cloud.ydb.v1.Alert.alert_template_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.ydb.v1.Alert.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.ydb.v1.Alert.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='notification_channels', full_name='yandex.cloud.ydb.v1.Alert.notification_channels', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='alert_parameters', full_name='yandex.cloud.ydb.v1.Alert.alert_parameters', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='alert_thresholds', full_name='yandex.cloud.ydb.v1.Alert.alert_thresholds', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2268,
  serialized_end=2554,
)


_MONITORINGCONFIG = _descriptor.Descriptor(
  name='MonitoringConfig',
  full_name='yandex.cloud.ydb.v1.MonitoringConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='alerts', full_name='yandex.cloud.ydb.v1.MonitoringConfig.alerts', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2556,
  serialized_end=2618,
)


_DEDICATEDDATABASE = _descriptor.Descriptor(
  name='DedicatedDatabase',
  full_name='yandex.cloud.ydb.v1.DedicatedDatabase',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_preset_id', full_name='yandex.cloud.ydb.v1.DedicatedDatabase.resource_preset_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='storage_config', full_name='yandex.cloud.ydb.v1.DedicatedDatabase.storage_config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scale_policy', full_name='yandex.cloud.ydb.v1.DedicatedDatabase.scale_policy', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='network_id', full_name='yandex.cloud.ydb.v1.DedicatedDatabase.network_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subnet_ids', full_name='yandex.cloud.ydb.v1.DedicatedDatabase.subnet_ids', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='assign_public_ips', full_name='yandex.cloud.ydb.v1.DedicatedDatabase.assign_public_ips', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2621,
  serialized_end=2851,
)


_SERVERLESSDATABASE = _descriptor.Descriptor(
  name='ServerlessDatabase',
  full_name='yandex.cloud.ydb.v1.ServerlessDatabase',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='throttling_rcu_limit', full_name='yandex.cloud.ydb.v1.ServerlessDatabase.throttling_rcu_limit', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='storage_size_limit', full_name='yandex.cloud.ydb.v1.ServerlessDatabase.storage_size_limit', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_throttling_rcu_limit', full_name='yandex.cloud.ydb.v1.ServerlessDatabase.enable_throttling_rcu_limit', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='provisioned_rcu_limit', full_name='yandex.cloud.ydb.v1.ServerlessDatabase.provisioned_rcu_limit', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='topic_write_quota', full_name='yandex.cloud.ydb.v1.ServerlessDatabase.topic_write_quota', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2854,
  serialized_end=3027,
)


_ZONALDATABASE = _descriptor.Descriptor(
  name='ZonalDatabase',
  full_name='yandex.cloud.ydb.v1.ZonalDatabase',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='zone_id', full_name='yandex.cloud.ydb.v1.ZonalDatabase.zone_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3029,
  serialized_end=3067,
)


_REGIONALDATABASE = _descriptor.Descriptor(
  name='RegionalDatabase',
  full_name='yandex.cloud.ydb.v1.RegionalDatabase',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='region_id', full_name='yandex.cloud.ydb.v1.RegionalDatabase.region_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3069,
  serialized_end=3112,
)


_SCALEPOLICY_FIXEDSCALE = _descriptor.Descriptor(
  name='FixedScale',
  full_name='yandex.cloud.ydb.v1.ScalePolicy.FixedScale',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='size', full_name='yandex.cloud.ydb.v1.ScalePolicy.FixedScale.size', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\003>=1', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3198,
  serialized_end=3233,
)

_SCALEPOLICY = _descriptor.Descriptor(
  name='ScalePolicy',
  full_name='yandex.cloud.ydb.v1.ScalePolicy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='fixed_scale', full_name='yandex.cloud.ydb.v1.ScalePolicy.fixed_scale', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_SCALEPOLICY_FIXEDSCALE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='scale_type', full_name='yandex.cloud.ydb.v1.ScalePolicy.scale_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\300\3011\001'),
  ],
  serialized_start=3115,
  serialized_end=3253,
)


_STORAGECONFIG = _descriptor.Descriptor(
  name='StorageConfig',
  full_name='yandex.cloud.ydb.v1.StorageConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='storage_options', full_name='yandex.cloud.ydb.v1.StorageConfig.storage_options', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\003>=1', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='storage_size_limit', full_name='yandex.cloud.ydb.v1.StorageConfig.storage_size_limit', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3255,
  serialized_end=3368,
)


_STORAGEOPTION = _descriptor.Descriptor(
  name='StorageOption',
  full_name='yandex.cloud.ydb.v1.StorageOption',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='storage_type_id', full_name='yandex.cloud.ydb.v1.StorageOption.storage_type_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='group_count', full_name='yandex.cloud.ydb.v1.StorageOption.group_count', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3370,
  serialized_end=3431,
)

_DATABASE_LABELSENTRY.containing_type = _DATABASE
_DATABASE.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_DATABASE.fields_by_name['status'].enum_type = _DATABASE_STATUS
_DATABASE.fields_by_name['storage_config'].message_type = _STORAGECONFIG
_DATABASE.fields_by_name['scale_policy'].message_type = _SCALEPOLICY
_DATABASE.fields_by_name['zonal_database'].message_type = _ZONALDATABASE
_DATABASE.fields_by_name['regional_database'].message_type = _REGIONALDATABASE
_DATABASE.fields_by_name['dedicated_database'].message_type = _DEDICATEDDATABASE
_DATABASE.fields_by_name['serverless_database'].message_type = _SERVERLESSDATABASE
_DATABASE.fields_by_name['labels'].message_type = _DATABASE_LABELSENTRY
_DATABASE.fields_by_name['backup_config'].message_type = yandex_dot_cloud_dot_ydb_dot_v1_dot_backup__pb2._BACKUPCONFIG
_DATABASE.fields_by_name['monitoring_config'].message_type = _MONITORINGCONFIG
_DATABASE_STATUS.containing_type = _DATABASE
_DATABASE.oneofs_by_name['database_type'].fields.append(
  _DATABASE.fields_by_name['zonal_database'])
_DATABASE.fields_by_name['zonal_database'].containing_oneof = _DATABASE.oneofs_by_name['database_type']
_DATABASE.oneofs_by_name['database_type'].fields.append(
  _DATABASE.fields_by_name['regional_database'])
_DATABASE.fields_by_name['regional_database'].containing_oneof = _DATABASE.oneofs_by_name['database_type']
_DATABASE.oneofs_by_name['database_type'].fields.append(
  _DATABASE.fields_by_name['dedicated_database'])
_DATABASE.fields_by_name['dedicated_database'].containing_oneof = _DATABASE.oneofs_by_name['database_type']
_DATABASE.oneofs_by_name['database_type'].fields.append(
  _DATABASE.fields_by_name['serverless_database'])
_DATABASE.fields_by_name['serverless_database'].containing_oneof = _DATABASE.oneofs_by_name['database_type']
_ALERTPARAMETER_DOUBLEPARAMETERVALUE.containing_type = _ALERTPARAMETER
_ALERTPARAMETER_INTEGERPARAMETERVALUE.containing_type = _ALERTPARAMETER
_ALERTPARAMETER_TEXTPARAMETERVALUE.containing_type = _ALERTPARAMETER
_ALERTPARAMETER_TEXTLISTPARAMETERVALUE.containing_type = _ALERTPARAMETER
_ALERTPARAMETER_LABELLISTPARAMETERVALUE.containing_type = _ALERTPARAMETER
_ALERTPARAMETER.fields_by_name['double_parameter_value'].message_type = _ALERTPARAMETER_DOUBLEPARAMETERVALUE
_ALERTPARAMETER.fields_by_name['integer_parameter_value'].message_type = _ALERTPARAMETER_INTEGERPARAMETERVALUE
_ALERTPARAMETER.fields_by_name['text_parameter_value'].message_type = _ALERTPARAMETER_TEXTPARAMETERVALUE
_ALERTPARAMETER.fields_by_name['text_list_parameter_value'].message_type = _ALERTPARAMETER_TEXTLISTPARAMETERVALUE
_ALERTPARAMETER.fields_by_name['label_list_parameter_value'].message_type = _ALERTPARAMETER_LABELLISTPARAMETERVALUE
_ALERTPARAMETER.oneofs_by_name['parameter'].fields.append(
  _ALERTPARAMETER.fields_by_name['double_parameter_value'])
_ALERTPARAMETER.fields_by_name['double_parameter_value'].containing_oneof = _ALERTPARAMETER.oneofs_by_name['parameter']
_ALERTPARAMETER.oneofs_by_name['parameter'].fields.append(
  _ALERTPARAMETER.fields_by_name['integer_parameter_value'])
_ALERTPARAMETER.fields_by_name['integer_parameter_value'].containing_oneof = _ALERTPARAMETER.oneofs_by_name['parameter']
_ALERTPARAMETER.oneofs_by_name['parameter'].fields.append(
  _ALERTPARAMETER.fields_by_name['text_parameter_value'])
_ALERTPARAMETER.fields_by_name['text_parameter_value'].containing_oneof = _ALERTPARAMETER.oneofs_by_name['parameter']
_ALERTPARAMETER.oneofs_by_name['parameter'].fields.append(
  _ALERTPARAMETER.fields_by_name['text_list_parameter_value'])
_ALERTPARAMETER.fields_by_name['text_list_parameter_value'].containing_oneof = _ALERTPARAMETER.oneofs_by_name['parameter']
_ALERTPARAMETER.oneofs_by_name['parameter'].fields.append(
  _ALERTPARAMETER.fields_by_name['label_list_parameter_value'])
_ALERTPARAMETER.fields_by_name['label_list_parameter_value'].containing_oneof = _ALERTPARAMETER.oneofs_by_name['parameter']
_NOTIFICATIONCHANNEL.fields_by_name['notify_about_statuses'].enum_type = _ALERTEVALUATIONSTATUS
_ALERT.fields_by_name['notification_channels'].message_type = _NOTIFICATIONCHANNEL
_ALERT.fields_by_name['alert_parameters'].message_type = _ALERTPARAMETER
_ALERT.fields_by_name['alert_thresholds'].message_type = _ALERTPARAMETER
_MONITORINGCONFIG.fields_by_name['alerts'].message_type = _ALERT
_DEDICATEDDATABASE.fields_by_name['storage_config'].message_type = _STORAGECONFIG
_DEDICATEDDATABASE.fields_by_name['scale_policy'].message_type = _SCALEPOLICY
_SCALEPOLICY_FIXEDSCALE.containing_type = _SCALEPOLICY
_SCALEPOLICY.fields_by_name['fixed_scale'].message_type = _SCALEPOLICY_FIXEDSCALE
_SCALEPOLICY.oneofs_by_name['scale_type'].fields.append(
  _SCALEPOLICY.fields_by_name['fixed_scale'])
_SCALEPOLICY.fields_by_name['fixed_scale'].containing_oneof = _SCALEPOLICY.oneofs_by_name['scale_type']
_STORAGECONFIG.fields_by_name['storage_options'].message_type = _STORAGEOPTION
DESCRIPTOR.message_types_by_name['Database'] = _DATABASE
DESCRIPTOR.message_types_by_name['AlertParameter'] = _ALERTPARAMETER
DESCRIPTOR.message_types_by_name['NotificationChannel'] = _NOTIFICATIONCHANNEL
DESCRIPTOR.message_types_by_name['Alert'] = _ALERT
DESCRIPTOR.message_types_by_name['MonitoringConfig'] = _MONITORINGCONFIG
DESCRIPTOR.message_types_by_name['DedicatedDatabase'] = _DEDICATEDDATABASE
DESCRIPTOR.message_types_by_name['ServerlessDatabase'] = _SERVERLESSDATABASE
DESCRIPTOR.message_types_by_name['ZonalDatabase'] = _ZONALDATABASE
DESCRIPTOR.message_types_by_name['RegionalDatabase'] = _REGIONALDATABASE
DESCRIPTOR.message_types_by_name['ScalePolicy'] = _SCALEPOLICY
DESCRIPTOR.message_types_by_name['StorageConfig'] = _STORAGECONFIG
DESCRIPTOR.message_types_by_name['StorageOption'] = _STORAGEOPTION
DESCRIPTOR.enum_types_by_name['AlertEvaluationStatus'] = _ALERTEVALUATIONSTATUS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Database = _reflection.GeneratedProtocolMessageType('Database', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _DATABASE_LABELSENTRY,
    '__module__' : 'yandex.cloud.ydb.v1.database_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.ydb.v1.Database.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _DATABASE,
  '__module__' : 'yandex.cloud.ydb.v1.database_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.ydb.v1.Database)
  })
_sym_db.RegisterMessage(Database)
_sym_db.RegisterMessage(Database.LabelsEntry)

AlertParameter = _reflection.GeneratedProtocolMessageType('AlertParameter', (_message.Message,), {

  'DoubleParameterValue' : _reflection.GeneratedProtocolMessageType('DoubleParameterValue', (_message.Message,), {
    'DESCRIPTOR' : _ALERTPARAMETER_DOUBLEPARAMETERVALUE,
    '__module__' : 'yandex.cloud.ydb.v1.database_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.ydb.v1.AlertParameter.DoubleParameterValue)
    })
  ,

  'IntegerParameterValue' : _reflection.GeneratedProtocolMessageType('IntegerParameterValue', (_message.Message,), {
    'DESCRIPTOR' : _ALERTPARAMETER_INTEGERPARAMETERVALUE,
    '__module__' : 'yandex.cloud.ydb.v1.database_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.ydb.v1.AlertParameter.IntegerParameterValue)
    })
  ,

  'TextParameterValue' : _reflection.GeneratedProtocolMessageType('TextParameterValue', (_message.Message,), {
    'DESCRIPTOR' : _ALERTPARAMETER_TEXTPARAMETERVALUE,
    '__module__' : 'yandex.cloud.ydb.v1.database_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.ydb.v1.AlertParameter.TextParameterValue)
    })
  ,

  'TextListParameterValue' : _reflection.GeneratedProtocolMessageType('TextListParameterValue', (_message.Message,), {
    'DESCRIPTOR' : _ALERTPARAMETER_TEXTLISTPARAMETERVALUE,
    '__module__' : 'yandex.cloud.ydb.v1.database_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.ydb.v1.AlertParameter.TextListParameterValue)
    })
  ,

  'LabelListParameterValue' : _reflection.GeneratedProtocolMessageType('LabelListParameterValue', (_message.Message,), {
    'DESCRIPTOR' : _ALERTPARAMETER_LABELLISTPARAMETERVALUE,
    '__module__' : 'yandex.cloud.ydb.v1.database_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.ydb.v1.AlertParameter.LabelListParameterValue)
    })
  ,
  'DESCRIPTOR' : _ALERTPARAMETER,
  '__module__' : 'yandex.cloud.ydb.v1.database_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.ydb.v1.AlertParameter)
  })
_sym_db.RegisterMessage(AlertParameter)
_sym_db.RegisterMessage(AlertParameter.DoubleParameterValue)
_sym_db.RegisterMessage(AlertParameter.IntegerParameterValue)
_sym_db.RegisterMessage(AlertParameter.TextParameterValue)
_sym_db.RegisterMessage(AlertParameter.TextListParameterValue)
_sym_db.RegisterMessage(AlertParameter.LabelListParameterValue)

NotificationChannel = _reflection.GeneratedProtocolMessageType('NotificationChannel', (_message.Message,), {
  'DESCRIPTOR' : _NOTIFICATIONCHANNEL,
  '__module__' : 'yandex.cloud.ydb.v1.database_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.ydb.v1.NotificationChannel)
  })
_sym_db.RegisterMessage(NotificationChannel)

Alert = _reflection.GeneratedProtocolMessageType('Alert', (_message.Message,), {
  'DESCRIPTOR' : _ALERT,
  '__module__' : 'yandex.cloud.ydb.v1.database_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.ydb.v1.Alert)
  })
_sym_db.RegisterMessage(Alert)

MonitoringConfig = _reflection.GeneratedProtocolMessageType('MonitoringConfig', (_message.Message,), {
  'DESCRIPTOR' : _MONITORINGCONFIG,
  '__module__' : 'yandex.cloud.ydb.v1.database_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.ydb.v1.MonitoringConfig)
  })
_sym_db.RegisterMessage(MonitoringConfig)

DedicatedDatabase = _reflection.GeneratedProtocolMessageType('DedicatedDatabase', (_message.Message,), {
  'DESCRIPTOR' : _DEDICATEDDATABASE,
  '__module__' : 'yandex.cloud.ydb.v1.database_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.ydb.v1.DedicatedDatabase)
  })
_sym_db.RegisterMessage(DedicatedDatabase)

ServerlessDatabase = _reflection.GeneratedProtocolMessageType('ServerlessDatabase', (_message.Message,), {
  'DESCRIPTOR' : _SERVERLESSDATABASE,
  '__module__' : 'yandex.cloud.ydb.v1.database_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.ydb.v1.ServerlessDatabase)
  })
_sym_db.RegisterMessage(ServerlessDatabase)

ZonalDatabase = _reflection.GeneratedProtocolMessageType('ZonalDatabase', (_message.Message,), {
  'DESCRIPTOR' : _ZONALDATABASE,
  '__module__' : 'yandex.cloud.ydb.v1.database_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.ydb.v1.ZonalDatabase)
  })
_sym_db.RegisterMessage(ZonalDatabase)

RegionalDatabase = _reflection.GeneratedProtocolMessageType('RegionalDatabase', (_message.Message,), {
  'DESCRIPTOR' : _REGIONALDATABASE,
  '__module__' : 'yandex.cloud.ydb.v1.database_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.ydb.v1.RegionalDatabase)
  })
_sym_db.RegisterMessage(RegionalDatabase)

ScalePolicy = _reflection.GeneratedProtocolMessageType('ScalePolicy', (_message.Message,), {

  'FixedScale' : _reflection.GeneratedProtocolMessageType('FixedScale', (_message.Message,), {
    'DESCRIPTOR' : _SCALEPOLICY_FIXEDSCALE,
    '__module__' : 'yandex.cloud.ydb.v1.database_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.ydb.v1.ScalePolicy.FixedScale)
    })
  ,
  'DESCRIPTOR' : _SCALEPOLICY,
  '__module__' : 'yandex.cloud.ydb.v1.database_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.ydb.v1.ScalePolicy)
  })
_sym_db.RegisterMessage(ScalePolicy)
_sym_db.RegisterMessage(ScalePolicy.FixedScale)

StorageConfig = _reflection.GeneratedProtocolMessageType('StorageConfig', (_message.Message,), {
  'DESCRIPTOR' : _STORAGECONFIG,
  '__module__' : 'yandex.cloud.ydb.v1.database_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.ydb.v1.StorageConfig)
  })
_sym_db.RegisterMessage(StorageConfig)

StorageOption = _reflection.GeneratedProtocolMessageType('StorageOption', (_message.Message,), {
  'DESCRIPTOR' : _STORAGEOPTION,
  '__module__' : 'yandex.cloud.ydb.v1.database_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.ydb.v1.StorageOption)
  })
_sym_db.RegisterMessage(StorageOption)


DESCRIPTOR._options = None
_DATABASE_LABELSENTRY._options = None
_ZONALDATABASE.fields_by_name['zone_id']._options = None
_REGIONALDATABASE.fields_by_name['region_id']._options = None
_SCALEPOLICY_FIXEDSCALE.fields_by_name['size']._options = None
_SCALEPOLICY.oneofs_by_name['scale_type']._options = None
_STORAGECONFIG.fields_by_name['storage_options']._options = None
# @@protoc_insertion_point(module_scope)
